@@ -31,7 +31,7 @@ our %DEFAULT_ATTRIBUTES_XPATH = (
     Manufacturer => [qw(ItemAttributes Manufacturer)],
     MediumImageUrl => [qw(MediumImage URL)],
     ImageUrlMedium => [qw(MediumImage URL)],
-    OurPrice => [qw(Offers Offer OfferListing Price FormattedPrice)],
+    OurPrice => [qw(ItemAttributes ListPrice FormattedPrice)],
     ImageUrlSmall => [qw(SmallImage URL)],
     SmallImageUrl => [qw(SmallImage URL)],
     SuperSaverShipping => [qw(Offers Offer OfferListing IsEligibleForSuperSaverShipping)],
